package com.ruoyi.system.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.domain.VipMembership;

/**
 * viplistMapper接口
 * 
 * @author ruoyi
 * @date 2023-05-24
 */
public interface VipMembershipMapper  extends BaseMapper<VipMembership>
{
    /**
     * 查询viplist
     * 
     * @param id viplist主键
     * @return viplist
     */
    public VipMembership selectVipMembershipById(Long id);

    /**
     * 查询viplist列表
     * 
     * @param vipMembership viplist
     * @return viplist集合
     */
    public List<VipMembership> selectVipMembershipList(VipMembership vipMembership);

    /**
     * 新增viplist
     * 
     * @param vipMembership viplist
     * @return 结果
     */
    public int insertVipMembership(VipMembership vipMembership);

    /**
     * 修改viplist
     * 
     * @param vipMembership viplist
     * @return 结果
     */
    public int updateVipMembership(VipMembership vipMembership);

    /**
     * 删除viplist
     * 
     * @param id viplist主键
     * @return 结果
     */
    public int deleteVipMembershipById(Long id);

    /**
     * 批量删除viplist
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteVipMembershipByIds(Long[] ids);
}
